"""Project configurations
"""

CROSS_ENCODER = "cross-encoder/ms-marco-TinyBERT-L-2-v2"
BI_ENCODER = "retrieve_rank"
INDEX="faiss_index"
DATA="data"
